<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
	register_activation_hook( __FILE__, 'rwmb_check_php_version' );

	/**
	 * Display notice for old PHP version.
	 */
	function rwmb_check_php_version() {
		if ( version_compare( phpversion(), '5.3', '<' ) ) {
			die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
		}
	}




	require_once dirname( __FILE__ ) . '/inc/loader.php';
	$rwmb_loader = new RWMB_Loader();
	$rwmb_loader->init();


	add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

	$prefix = '_cmb_';


  // Open Code


   

    $meta_boxes[] = array(

        'id'         => 'post_setting',

        'title'      => 'Post Setting',

        'pages'      => array('post'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

            array(

                'name' => 'Select',

                'desc' => 'Select type to show sidebar',

                'id'   => $prefix . 'post_select',

                'type'    => 'select',

                'options'   => array(

                    array( 'value' => 'left', 'name' => 'Sidebar Left' ),

                    array( 'value' => 'right', 'name' => 'Sidebar Right'),

                    ),

                'placeholder'     => 'Select an Item',

                    ),
            array(

                'name' => 'Image:',

                'desc' => 'Show in blog page',

                'default' => '',

                'id' => $prefix . 'image123',

                'type' => 'file'

            ),
            array(
                'name' => 'Video Link',
                'desc' => 'Video Link',
                'default' => '',
                'id' => $prefix . 'video_link',
                'type' => 'text'
            ),
            array(
                'name' => 'Video Thumbnail:',
                'desc' => 'Video Thumbnail',
                'default' => '',
                'id' => $prefix . 'video_image',
                'type' => 'file'
            ),
            array(
                'name' => 'Audio Iframe',
                'desc' => 'Audio Iframe',
                'default' => '',
                'id' => $prefix . 'audio_iframe',
                'type' => 'text'
            ),
            array(

                'name' => 'Link share facebook:',

                'desc' => 'Input Link share facebook',

                'id'   => $prefix . 'single_facebook',

                'type'    => 'text',

            ),

            array(

                'name' => 'Link share twitter:',

                'desc' => 'Input Link share twitter',

                'id'   => $prefix . 'single_twitter',

                'type'    => 'text',

            ),

        

            array(

                'name' => 'Link share youtube:',

                'desc' => 'Input Link share youtube',

                'id'   => $prefix . 'single_youtube',

                'type'    => 'text',

            ),



        )

    );



$meta_boxes[] = array(

        'id'         => 'testimonial_setting',

        'title'      => 'Testimonial Setting',

        'pages'      => array('testimonial'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

        array(

                'name' => 'Job:',

                'desc' => '',

                'default' => '',

                'id' => $prefix . 'job',

                'type' => 'text'

            ), 

        array(

                'name' => 'Positioning',

                'desc' => 'Example: left: calc(50% - 40px); top: 75px;',

                'default' => '',

                'id' => $prefix . 'positioning',

                'type' => 'text'

            ),

        )

    );



$meta_boxes[] = array(

        'id'         => 'testimonial2_setting',

        'title'      => 'Testimonial 2 Setting',

        'pages'      => array('testimonial2'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

        array(

                'name' => 'Job:',

                'desc' => '',

                'default' => '',

                'id' => $prefix . 'job',

                'type' => 'text'

            ), 

        array(

                'name' => 'Signature:',

                'desc' => 'Signature',

                'default' => '',

                'id' => $prefix . 'signature',

                'type' => 'file'

            ),

        )

    );





$meta_boxes[] = array(

        'id'         => 'team_setting',

        'title'      => 'team Setting',

        'pages'      => array('team'), // Post type

        'context'    => 'normal',

        'priority'   => 'high',

        'show_names' => true, // Show field names on the left

        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox

        'fields' => array(

             array(

                'name' => 'Job',

                'desc' => 'Job',

                'default' => '',

                'id' => $prefix . 'team_job',

                'type' => 'text'

            ), 

             array(

                'name' => 'Link twitter:',

                'desc' => 'Input link twitter',

                'id'   => $prefix . 'team_twitter',

                'type'    => 'text',

            ),

              array(

                'name' => 'Link facebook:',

                'desc' => 'Input link facebook',

                'id'   => $prefix . 'team_facebook',

                'type'    => 'text',

            ),

              array(

                'name' => 'Link dribbble:',

                'desc' => 'Input link dribbble',

                'id'   => $prefix . 'team_dribbble',

                'type'    => 'text',

            ),   

        )

    );






// End Code



    return $meta_boxes;
});
}
